@@ -28,7 +28,7 @@ FGIntegerComponent::MatchAndRankComponent(FGString& fnameRemainder,
     return false;
   }
 
-  int digits = 0;
+  unsigned int digits = 0;
   // Build up the number here
   FGString theInt;
 
