@@ -36,11 +36,13 @@ public:
 
   // Get methods
   unsigned int GetLength(void) const;
-  char operator[](int pos) const;
+  char operator[](unsigned int pos) const;
 
   // Substring methods
-  FGString Left(int num) const;
-  FGString Right(int num) const;
+  FGString Left(unsigned int num) const;
+  FGString Right(unsigned int num) const;
+
+  bool Contains(char c) const;
 
   // Conversions
   int AToI(void) const;
